==> downloads.html?file=gigkalender_v1.2.66_002.zip: gigkalender/admin/delUser.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  if ( isset($_POST['uid'])
       && loggedIn() )
  {
    $FormularKorrektAusgefuellt = true;
  }


  echo '<p class="Headline">'.$L_Headline17.'</p>';

      if ( !loggedIn() ) { echo $L_003; }
      else
      {
        if ( !IsUserAdmin() ) { echo $L_015; }
        else
        {
        // Inhalt hier einfügen
          if (isset($_POST['uid']))
      	 {
        	   if ($_POST['delUser']==$L_Button23)
        	   {
              $UserName = $_POST['uid'];
              // Maskieren spezieller Zeichen für die Verwendung in einer SQL-Anweisung
                $UserName = mysql_real_escape_string($UserName);

              // Datensatz-Loeschvorgang festlegen
              $SQL_Befehl = "DELETE FROM ".$prefix."user WHERE UserName = '$UserName'";

              // Datensatz-L&ouml;schvorgang durchf&uuml;hren
              $resultat = mysql_db_query($db_name, $SQL_Befehl);

              if ($resultat) { echo $L_046.'<br />'; }
              else { echo $L_047.'<br />'; }
        	   }
        	   if ($_POST['delUser']==$L_Button24)
        	   {
              echo $L_048.'<br />';
        	   }
      	 }
    	 else
    	 {
      	   echo $L_045.'<br /><br />';
      	   $uid = $_GET['uid'];
      	   echo '
        	     <form method="post" action="index.php?submenue=admin&amp;inhalt=delUser" accept-charset="UTF-8">
        	       <fieldset>
                   <input name="delUser" type="submit" value="'.$L_Button23.'" class="button" />
                   <input name="delUser" type="submit" value="'.$L_Button24.'" class="button" />
                   <input name="uid" id="uid" type="hidden" value="'.$uid.'" />
                   <input type="hidden" name="http-equiv" value="showUsers" />
                 </fieldset>
      	     </form>';
    	 }
        // Inhalt zuende
      }
      }
    ?>

==> downloads.html?file=gigkalender_v1.2.75_017.zip: gigkalender/admin/delUser.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  if ( loggedIn() && isset($_GET['uid']) && $_GET['uid']!=getCurrentUserVar('UserName') )
    $FormularKorrektAusgefuellt = true;
  else
    $FormularKorrektAusgefuellt = false;
  echo '<p class="Headline">'.$L_Headline17.'</p>';

      if ( !loggedIn() ) { echo $L_003; }
      else
      {
        if ( !IsUserAdmin() ) { echo $L_015; }
        else
        {
        // Inhalt hier einfügen
        if ($FormularKorrektAusgefuellt == true) {
          if (isset($_POST['uid']))
      	 {
        	   if ($_POST['delUser']==$L_Button23)
        	   {
              $UserName = $_POST['uid'];
              // Maskieren spezieller Zeichen für die Verwendung in einer SQL-Anweisung
                $UserName = mysqli_real_escape_string($db, $UserName);

              // Datensatz-Loeschvorgang festlegen
              $SQL_Befehl = "DELETE FROM ".$prefix."user WHERE UserName = '$UserName'";

              // Datensatz-L&ouml;schvorgang durchf&uuml;hren
              $resultat = mysqli_query($db, $SQL_Befehl);

              if ($resultat) { echo $L_046.'<br />'; }
              else { echo $L_047.'<br />'; }
        	   }
        	   if ($_POST['delUser']==$L_Button24)
        	   {
              echo $L_048.'<br />';
        	   }
      	 }
    	 else
    	 {
      	   echo $L_045.'<br /><br />';
      	   $uid = $_GET['uid'];
      	   echo '
        	     <form method="post" action="index.php?submenue=admin&amp;inhalt=delUser" accept-charset="UTF-8">
        	       <fieldset>
                   <input name="delUser" type="submit" value="'.$L_Button23.'" class="button" />
                   <input name="delUser" type="submit" value="'.$L_Button24.'" class="button" />
                   <input name="uid" id="uid" type="hidden" value="'.$uid.'" />
                   <input type="hidden" name="http-equiv" value="showUsers" />
                 </fieldset>
      	     </form>';
    	 }}
        // Inhalt zuende
      }
      }
    ?>
